Form4Controller class

Constructors

Form4Controller()

Properties

fieldErrors ↔ Map<String, String>
getter/setter pair
fields ↔ Map<String, Form4Field<Object?>>
getter/setter pair
formKey ↔ GlobalKey<FormState>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addField<T>(Form4Field<T> field) → void
clearFieldErrors() → void
currentValuesFor(List<String> fieldNames) → Map<String, Object?>
currentValuesForNonSkippedFields() → Map<String, dynamic>
currentValuesForSkippedFields() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setFieldError(String fieldName, String errorMsg) → void
setFieldErrors(Map<String, String> fieldErrorMap) → void
toString() → String
A string representation of this object.
inherited
validate() → bool
validateAndSave({required Future<SaveResult> saveWork()?, void onFailure(SaveResult result)?, void onSuccess(SaveResult result)?}) → void
validator<T>(Form4FieldState<T> field) → FormFieldValidator<T>

Operators

operator ==(Object other) → bool
The equality operator.
inherited