Form4FieldConfig class

Constructors

Form4FieldConfig({bool showLabel = true, bool leftRightLabel = false, int labelWidthPercent = 30, int widthPercent = 100, bool skipInValueCollection = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
labelWidthPercent → int
It is the percentage inside the widthPercent
final
leftRightLabel → bool
final
placeLabelAtTop → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLabel → bool
final
skipInValueCollection → bool
final
widthPercent → int
This defines the overall widget percent in the available row space
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited